#include "glstreamrenderer.h"

GLStreamRenderer::GLStreamRenderer(QWidget *parent) : QGLWidget(parent)
{
}

GLStreamRenderer::~GLStreamRenderer()
{
    //dtor
}

 QSize GLStreamRenderer::minimumSizeHint() const
 {
     return QSize(50, 50);
 }

 QSize GLStreamRenderer::sizeHint() const
 {
     return QSize(640 , 480);
 }

void GLStreamRenderer::connectIOhandler(IOImageHandler *i)
{
    connect(i,SIGNAL(SIG_imageWritten()),this,SLOT(updateTexture()));
    imHandler = i;
}

 void GLStreamRenderer::initializeGL()
 {
     qglClearColor(QColor::fromCmykF(0.39, 0.39, 0.0, 0.0));
     glShadeModel(GL_FLAT);
     glEnable(GL_TEXTURE_2D);
     //glEnable(GL_DEPTH_TEST);
     //glEnable(GL_CULL_FACE);
 }

 void GLStreamRenderer::resizeGL(int width, int height)
 {
     //int side = qMin(width, height);
     glViewport(0,0, width, height);
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
     glOrtho(0.0, 100.0, 0.0, 100.0, -1.0, 15.0);
     glMatrixMode(GL_MODELVIEW);
 }

  void GLStreamRenderer::paintGL()
 {
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
     glLoadIdentity();
     glBindTexture(GL_TEXTURE_2D, currentTexture);
     quad(0,0,100,0,100,100,0,100);
 }

//the texture will be updated If data is written to the stream
 void GLStreamRenderer::updateTexture()
 {
    *(imHandler->dataStream) >> currentImage;
    //std::cout << *(imHandler->dataStream)
    (imHandler->theIODevice)->reset();
    std::cout << "TEXTURE UPDATED" << std::endl;
    std::cout << currentImage.height() << " " << currentImage.width() << std::endl;
    currentTexture = bindTexture(currentImage);
    update();
 }

  void GLStreamRenderer::updateTexture(const QPixmap &pmap)
 {
    //std::cout << "TEXTURE UPDATED" << std::endl;
    //std::cout << im.height() << " " << im.width() << std::endl;
    currentTexture = bindTexture(pmap);
    update();
 }

 void GLStreamRenderer::updateAndStoreTexture(const QPixmap &pmap)
 {
    //std::cout << "TEXTURE UPDATED" << std::endl;
    //std::cout << im.height() << " " << im.width() << std::endl;
    currentTexture = bindTexture(pmap);
    textures.push_back(currentTexture);
    //currentTexture
    update();
 }

 void GLStreamRenderer::selectTexture(int i)
 {
    currentTexture = textures.at(i);
    update();
 }

  void GLStreamRenderer::quad(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2,
                     GLdouble x3, GLdouble y3, GLdouble x4, GLdouble y4)
 {
     glBegin(GL_QUADS);
     glTexCoord2d(0.0,0.0); glVertex3d(x1, y1, 0);
     glTexCoord2d(1.0,0.0); glVertex3d(x2, y2, 0);
     glTexCoord2d(1.0,1.0); glVertex3d(x3, y3, 0);
     glTexCoord2d(0.0,1.0); glVertex3d(x4, y4, 0);
     glEnd();
 }
